@@ -18,11 +18,11 @@ use YAML qw/Dump LoadFile/;
 use Readonly;
 use Template;
 use Template::Provider;
-use Data::Merger qw/merger/;
 use File::ShareDir qw/dist_dir/;
+use JSON qw/decode_json/;
 use base qw/Exporter/;
 
-our $VERSION     = version->new('0.5.9');
+our $VERSION     = version->new('0.6.0');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
@@ -143,7 +143,7 @@ sub add_args {
 
             # merge the argument on to the args hash
             my ($arg, $value) = split /=/, $file, 2;
-            $default->{args}->{$arg} = $value;
+            $default->{args}->{$arg} = eval { decode_json($value) } || $value;
         }
         else {
 
@@ -340,7 +340,7 @@ App::TemplateCMD - Sets up an interface to passing Template Toolkit templates
 
 =head1 VERSION
 
-This documentation refers to App::TemplateCMD version 0.5.9.
+This documentation refers to App::TemplateCMD version 0.6.0.
 
 =head1 SYNOPSIS
 
