@@ -18,7 +18,7 @@ use Template::Provider;
 use IPC::Open2;
 use base qw/App::TemplateCMD::Command/;
 
-our $VERSION     = version->new('0.5.9');
+our $VERSION     = version->new('0.6.0');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
@@ -26,13 +26,18 @@ sub process {
     my ($self, $cmd, %option) = @_;
 
     my $template = shift @{$option{files}};
-    my $args     = { %{ $cmd->config || {} }, %option, %{ $option{args} || {} } };
+    my $args     = $cmd->conf_join(
+        $cmd->conf_join( ( $cmd->config || {} ), ( $option{args} || {} ) ),
+        \%option
+    );
 
     confess "No template passed!\n" if !$template;
 
     my $out = '';
     $cmd->{template}->process( $template, $args, \$out );
     warn  $cmd->{template}->error . "\n" if $cmd->{template}->error && $cmd->{template}->error !~ /^file error - .*: not a file$/;
+    $Data::Dumper::Indent = 1;
+    print Dumper $cmd->{template};
 
     if (!$out) {
         my @files = uniq sort map {$_->{file}} $cmd->list_templates();
@@ -119,7 +124,7 @@ App::TemplateCMD::Command::Print - Prints a parsed template out to screen or fil
 
 =head1 VERSION
 
-This documentation refers to App::TemplateCMD::Command::Print version 0.5.9.
+This documentation refers to App::TemplateCMD::Command::Print version 0.6.0.
 
 =head1 SYNOPSIS
 
